#
# spec file
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
#                         University Research and Technology
#                         Corporation.  All rights reserved.
# Copyright (c) 2004-2005 The University of Tennessee and The University
#                         of Tennessee Research Foundation.  All rights
#                         reserved.
# Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
#                         University of Stuttgart.  All rights reserved.
# Copyright (c) 2004-2005 The Regents of the University of California.
#                         All rights reserved.
# Copyright (c) 2006-2016 Cisco Systems, Inc.  All rights reserved.
# Copyright (c) 2013      Mellanox Technologies, Inc.
#                         All rights reserved.
# Copyright (c) 2015      Research Organization for Information Science
#                         and Technology (RIST). All rights reserved.
# Copyright (c) 2003, The Regents of the University of California, through
# Lawrence Berkeley National Laboratory (subject to receipt of any
# required approvals from the U.S. Dept. of Energy).  All rights reserved.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor testsuite%{nil}

# Static libraries are disabled by default
# for non HPC builds
# To enable them, simply uncomment:
# % define build_static_devel 1

%define pname openmpi
%define vers 2.1.6
%define _vers 2_1_6
%define m_f_ver 2
%bcond_with ringdisabled

%if "%flavor" == ""
ExclusiveArch:  do_not_build
 %{bcond_with hpc}
 %define package_name %pname%{m_f_ver}
%else
 # Trickery for OBS Staging. If _with_ringdisabled is set
 # we only want to build the flavors required by other rings packages.
 # Do not build any other ones
 %if %{with ringdisabled}
  %if "%flavor" != "standard"
ExclusiveArch:  do_not_build
  %endif
 %endif

  %if "%flavor" == "standard" || "%flavor" == "testsuite"
    %define package_name   %{pname}%{m_f_ver}
    %bcond_with hpc
    %if "%flavor" == "testsuite"
      %define testsuite 1
    %endif
  %else
    %bcond_without hpc
# Needs to be defined here to avoid hen/egg problem with test packages.
    %define package_name %{pname}_%{_vers}-%{compiler_family}%{?c_f_ver}-hpc
    %define build_static_devel 1
  %endif
%endif

%if "%flavor" == "gnu-hpc"
%define compiler_family gnu
%undefine c_f_ver
%endif

%if "%flavor" == "gnu7-hpc"
%define compiler_family gnu
%define c_f_ver 7
%endif

%if "%flavor" == "gnu-hpc-testsuite"
%define compiler_family gnu
%undefine c_f_ver
%define testsuite 1
%endif

%if "%flavor" == "gnu7-hpc-testsuite"
%define compiler_family gnu
%define c_f_ver 7
%define testsuite 1
%endif

%if 0%{?suse_version} >= 1320
%ifarch aarch64 %power64 x86_64 s390x
%define with_ucx 1
%endif
%endif

# Detect whether we are the default openMPI implemantation or not
# openmpi2 is default for SLE/Leap 15.[0-3]
%if "%{flavor}" == "standard" && %{suse_version} == 1500 && 0%{?sle_version} <= 150300
%define default_openmpi 1
%else
%define default_openmpi 0
%endif

%if %{with hpc}
%{!?compiler_family:%global compiler_family gnu}
%{hpc_init -M -c %compiler_family %{?c_f_ver:-v %{c_f_ver}} -m openmpi %{?mpi_f_ver:-V %{mpi_f_ver}}}

%global hpc_openmpi_dep_version %(VER=%m_f_ver; echo -n ${VER})
%global hpc_openmpi_dir openmpi%{hpc_openmpi_dep_version}
%global hpc_openmpi_pack_version %{hpc_openmpi_dep_version}
%endif

%define git_ver .0.d9b9e59e5c5a

#############################################################################
#
# Preamble Section
#
#############################################################################

Name:           %{package_name}%{?testsuite:-testsuite}
Version:        %{vers}
Release:        150500.24.2.1
Summary:        An implementation of MPI/SHMEM
License:        BSD-3-Clause
Group:          Development/Libraries/Parallel
URL:            http://www.open-mpi.org/
Source0:        openmpi-%{version}%{git_ver}.tar.bz2
Source2:        openmpi2-rpmlintrc
Source3:        macros.hpc-openmpi
Source4:        mpivars.sh
Source5:        mpivars.csh
Patch0:         fix-rdma-component-selection.patch
Patch1:         reproducible.patch
Patch2:         add-gen-p5-chip-pci-id-to-ini-file.patch
Patch3:         openmpi_disable_opal_fifo_test_issue5470.patch
Patch4:         Fix-error-with-stricter-quoting-requirements-of-autoconf-2.70.patch
Patch5:         Always-include-the-stddef.h-header.patch
Patch6:         btl-openib-Add-support-for-newer-hardware.patch
Provides:       mpi
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  libibumad-devel
BuildRequires:  libibverbs-devel
BuildRequires:  libtool
# net-tools is required to run hostname
BuildRequires:  net-tools
%if 0%{?testsuite}
BuildArch:      noarch
BuildRequires:  %{package_name} = %{version}
%endif
%if 0%{?with_ucx}
BuildRequires:  libucm-devel
BuildRequires:  libucp-devel
BuildRequires:  libucs-devel
BuildRequires:  libuct-devel
%endif
%if %{without hpc}
BuildRequires:  Modules
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  mpi-selector
Requires:       mpi-selector
Requires(preun):mpi-selector
Requires:       %{package_name}-libs = %{version}
%else
BuildRequires:  %{compiler_family}%{?c_f_ver}-compilers-hpc-macros-devel
BuildRequires:  lua-lmod
BuildRequires:  suse-hpc
%if 0%{!?testsuite:1}
Requires:       lib%{package_name} = %{version}
%endif
%hpc_requires
%endif

%ifarch %{ix86} x86_64
BuildRequires:  infinipath-psm-devel
BuildRequires:  libfabric-devel
%endif

%ifarch x86_64
BuildRequires:  libnuma-devel
BuildRequires:  libpsm2-devel
BuildRequires:  numactl
%endif

Requires:       openmpi-runtime-config
Recommends:     openmpi%{m_f_ver}-config
%if 0%{?default_openmpi}
Provides:       openmpi = %{version}
%endif
# OpenMPI requires ssh (or rsh) to run even on a single host
# Force ssh to make sure the install works out of the box
Requires:       openssh

%if %{without hpc}
%define mpi_prefix %{_libdir}/mpi/gcc/openmpi%{m_f_ver}

%define mpi_bindir %{mpi_prefix}/bin
%define mpi_libdir %{mpi_prefix}/%{_lib}
%define mpi_datadir %{mpi_prefix}/share
%define mpi_helpdir %{mpi_datadir}/%{pname}%{m_f_ver}
%define mpi_includedir %{mpi_prefix}/include
%define mpi_mandir %{mpi_prefix}/share/man
%else
%define mpi_prefix %hpc_prefix

%define mpi_bindir %hpc_bindir
%define mpi_libdir %hpc_libdir
%define mpi_datadir %hpc_datadir
%define mpi_helpdir %{mpi_datadir}/openmpi
%define mpi_includedir %hpc_includedir
%define mpi_mandir %hpc_mandir

%endif

%description
%if 0%{?testsuite}
This package is just needed to run the testsuite and does not contain
anything interesting.
%else
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

OpenMPI also includes an implementation of the OpenSHMEM parallel
programming API, which is a Partitioned Global Address Space (PGAS)
abstraction layer providing inter-process communication using
one-sided communication techniques.

This package provides general tools (mpirun, mpiexec, etc.) and the
Module Component Architecture (MCA) base and plugins necessary for
running Open MPI/OpenSHMEM jobs.
%endif

%if 0%{!?testsuite:1}
%package        %{!?with_hpc:libs}%{?with_hpc:-n lib%{name}}
Summary:        OpenMPI runtime libraries for OpenMPI %{?with_hpc:HPC} version %{version}
Group:          System/Libraries
Requires:       %{name} = %{version}
%if 0%{?default_openmpi}
Provides:       openmpi-libs = %{version}
%endif
%{?with_hpc:%hpc_requires}

%description %{!?with_hpc:libs}%{?with_hpc:-n lib%{name}}
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

OpenMPI also includes an implementation of the OpenSHMEM parallel
programming API, which is a Partitioned Global Address Space (PGAS)
abstraction layer providing inter-process communication using
one-sided communication techniques.

This subpackage provides the OpenMPI shared libraries.

%package        devel
Summary:        SDK for openMPI %{?with_hpc:HPC} version %{version}
Group:          Development/Libraries/Parallel
Requires:       libibumad-devel
Requires:       libibverbs-devel
%if %{without hpc}
Requires:       libstdc++-devel
%if 0%{?default_openmpi}
Provides:       openmpi-devel = %{version}
%endif
%else
%hpc_requires_devel
%endif
Requires:       %{name} = %{version}

%description devel
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

OpenMPI also includes an implementation of the OpenSHMEM parallel
programming API, which is a Partitioned Global Address Space (PGAS)
abstraction layer providing inter-process communication using
one-sided communication techniques.

This subpackage provides the development files for Open MPI/OpenSHMEM,
such as wrapper compilers and header files for MPI/OpenSHMEM
development.

%package docs
Summary:        Documentation for Open MPI/SHMEM %{?with_hpc:HPC} version %{version}
Group:          Development/Documentation
Requires:       %{name} = %{version}

%description docs
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

OpenMPI also includes an implementation of the OpenSHMEM parallel
programming API, which is a Partitioned Global Address Space (PGAS)
abstraction layer providing inter-process communication using
one-sided communication techniques.

This subpackage provides the documentation for Open MPI/OpenSHMEM.

%package        macros-devel
Summary:        Macros for openMPI version %{version}
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel = %{version}
# Make sure no two openmpi macro file can be installed at once
Provides:       %{pname}-macros-provider = %{version}
Conflicts:      otherproviders(%{pname}-macros-provider)
# Conflict (without providing) with the older openmpi-hpc-macros-devel flag
# to avoid issue with older packages
Conflicts:      otherproviders(%{pname}-hpc-macros-devel)

%if 0%{?default_openmpi}
Provides:       openmpi-macros-devel = %{version}
%endif

%description macros-devel
Macros for building RPM packages for OpenMPI version %{version}.

%if 0%{?build_static_devel}
%package        devel-static
Summary:        Static libraries for openMPI %{?with_hpc:HPC} version %{version}
Group:          Development/Libraries/Parallel
Requires:       %{name}-devel = %{version}
%if 0%{?default_openmpi}
Provides:       openmpi-devel-static = %{version}
%endif

%description devel-static
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

This RPM contains the static library files, which are packaged separately from
the dynamic library and headers.
%endif

%if %{without hpc}
%package        -n %{pname}%{m_f_ver}-config
Summary:        Runtime configuration files for openMPI %{?with_hpc:HPC} version %{version}
Group:          Development/Libraries/Parallel
Provides:       openmpi-runtime-config = %{version}
Conflicts:      otherproviders(openmpi-runtime-config)

%description -n %{pname}%{m_f_ver}-config
OpenMPI is an implementation of the Message Passing Interface, a
standardized API typically used for parallel and/or distributed
computing. OpenMPI is the merged result of four prior implementations
where the team found for them to excel in one or more areas,
such as latency or throughput.

This RPM contains the configuration files for OpenMPI runtime (Version 1 or 2).
%endif

%if %{with hpc}
%{hpc_master_package -L -a}
%{hpc_master_package -l}
%{hpc_master_package devel}
%{hpc_master_package docs}
%{hpc_master_package macros-devel}
%{hpc_master_package -a devel-static}
%endif # ?with_hpc
%endif # !testsuite

#############################################################################
#
# Prepatory Section
#
#############################################################################
%prep
echo FLAVOR %{flavor}
%if %{with hpc}
echo with HPC
%endif
%if %{without hpc}
echo without HPC
%endif
%setup -q -n  openmpi-%{version}%{git_ver}
%patch0
%if %{without hpc}
cat > %{_sourcedir}/baselibs.conf  <<EOF
openmpi%{m_f_ver}-libs
EOF
%endif
%patch1 -p1
%patch2
%patch3 -p1
%patch4
%patch5
%patch6
# Live patch the VERSION file
sed -i -e 's/^greek=.*$/greek=%{git_ver}/' -e 's/^repo_rev=.*$/repo_rev=%{version}%{git_ver}/' \
       -e 's/^date=.*$/date="OpenMPI %{version} Distribution for SUSE"/' VERSION

#############################################################################
#
# Build Section
#
#############################################################################

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
export USER=OBS
export HOSTNAME=OBS
%{?with_hpc:%hpc_debug}
./autogen.pl --force
%if %{with hpc}
%{hpc_setup}
%{hpc_configure} \
%else
%{configure} \
           --prefix="%{mpi_prefix}" \
           --exec-prefix="%{mpi_prefix}" \
           --bindir="%{mpi_bindir}" \
           --datadir="%{mpi_datadir}" \
           --includedir="%{mpi_includedir}" \
           --libdir="%{mpi_libdir}" \
           --mandir="%{mpi_mandir}" \
%endif
           %{?build_static_devel:--enable-static}  \
           %{!?build_static_devel:--disable-static}  \
           --enable-builtin-atomics \
           --with-libltdl=%{_prefix} \
           --with-verbs \
           --enable-mpi-thread-multiple \
           --disable-wrapper-rpath \
%if 0%{?with_ucx}
           --with-ucx \
           --with-ucx-libdir=/usr/%_lib \
%endif
%ifarch %{ix86} x86_64
           --with-psm \
%endif
%ifarch x86_64
           --with-psm2 \
%endif
           --disable-silent-rules \
           --enable-mpirun-prefix-by-default \
           --with-package-string="Open MPI Distribution for SUSE"  \
           --disable-wrapper-rpath
make %{?_smp_mflags}

%if 0%{?testsuite}
%check
make check

%install

%files
%defattr(-, root, root)
%doc README
%doc test/util/test-suite.log

%else # ?testsuite

#############################################################################
#
# Install Section
#
#############################################################################

%install
%{?with_hpc:%{hpc_setup_compiler}}
make install DESTDIR="%buildroot"

# sanitize .la files
list="$(find %{buildroot} -name "*.la" -printf "%%h\n" | sort | uniq)"
for dir in ${list}
do
    deps="${deps} -L${dir##%{buildroot}}"
done
for dir in ${list}
do
%if !0%{?build_static_devel}
    rm -f ${dir}/*.la
%else
    for file in ${dir}/*.la
    do
        sed -i -e "s@ [^[:space:]]*home[^[:space:]\']*@${deps}@" \
            -e "s@ [^[:space:]]*home[^[:space:]\']*@@g" \
            -e "s@-L.*.libs @@g" ${file}
    done
%endif
done
##even with disable static this one gets generated
%{!?build_static_devel:rm -f %{buildroot}%{mpi_libdir}/libvt-pomp.a}

# GCC 5 builds the ignore-tkr extension and there is no way to
# turn that off
rm -f %{buildroot}%{mpi_libdir}/mpi_ext.mod

%fdupes %{buildroot}%{mpi_mandir}
%fdupes %{buildroot}%{mpi_datadir}
%fdupes %{buildroot}%{mpi_libdir}/pkgconfig

%if %{without hpc}
# make and install mpivars files
sed -e 's,prefix,%{mpi_prefix},g' -e 's,libdir,%{mpi_libdir},g' %{SOURCE4} \
    > %{buildroot}%{mpi_bindir}/mpivars.sh
sed -e 's,prefix,%{mpi_prefix},g' -e 's,libdir,%{mpi_libdir},g' %{SOURCE5} \
    > %{buildroot}%{mpi_bindir}/mpivars.csh

mkdir -p %{buildroot}%{_datadir}/modules/gnu-openmpi
cat << EOF > %{buildroot}%{_datadir}/modules/gnu-openmpi/%{version}
#%%Module
proc ModulesHelp { } {
        global dotversion
        puts stderr "\tLoads the gnu - openmpi %{version}  Environment"
}

module-whatis  "Loads the gnu openmpi %{version} Environment."
conflict gnu-openmpi
prepend-path PATH %{mpi_bindir}
prepend-path INCLUDE %{mpi_includedir}
prepend-path INCLUDE %{mpi_libdir}
prepend-path MANPATH %{mpi_mandir}
prepend-path LD_LIBRARY_PATH %{mpi_libdir}

EOF

mkdir -p %{buildroot}%{_rpmmacrodir}
cat <<EOF >%{buildroot}%{_rpmmacrodir}/macros.openmpi
#
# openmpi
#
%openmpi_prefix %{mpi_prefix}
%setup_openmpi  source %{mpi_bindir}/mpivars.sh

%openmpi_requires Requires: %{name}-libs
%openmpi_devel_requires Requires: %{name}-devel

EOF
%else
%hpc_write_modules_files
#%%Module1.0#####################################################################

proc ModulesHelp { } {

puts stderr " "
puts stderr "This module loads the %{pname} library built with the %{compiler_family} toolchain."
puts stderr "\nVersion %{version}\n"

}
module-whatis "Name: %{pname} built with %{compiler_family} toolchain"
module-whatis "Version: %{version}"
module-whatis "Category: runtime library"
module-whatis "Description: %{SUMMARY:0}"
module-whatis "URL: %{url}"

set     version                     %{version}

setenv          MPI_DIR             %{hpc_mpi_install_path}
prepend-path    PATH                %{hpc_bindir}
prepend-path    MANPATH             %{hpc_mandir}
prepend-path    LD_LIBRARY_PATH     %{hpc_libdir}
prepend-path    MODULEPATH          %{hpc_modulepath}
%{hpc_modulefile_add_pkgconfig_path}

family "MPI"
EOF
cat <<EOF >  %{buildroot}/%{mpi_bindir}/mpivars.sh
%hpc_setup_compiler
module load %{hpc_mpi_family}%{?pack_suff}/%{version}
EOF
sed -e "s/export/setenv/" -e "s/=/ /" \
    %{buildroot}/%{mpi_bindir}/mpivars.sh > \
    %{buildroot}/%{mpi_bindir}/mpivars.csh
mkdir -p %{buildroot}%{_rpmmacrodir}
cp %{S:3} %{buildroot}%{_rpmmacrodir}

# Drop the files that should go into %{pname}-config as we only package them
# in the non HPC build
rm -f %{buildroot}%{_sysconfdir}/openmpi-default-hostfile
rm -f %{buildroot}%{_sysconfdir}/openmpi-mca-params.conf
rm -f %{buildroot}%{_sysconfdir}/openmpi-totalview.tcl
%endif

%if %{without hpc}
%post
# Always register. We might be already registered in the case of an udate
# but mpi-selector handles it fine
/usr/bin/mpi-selector \
        --register %{name} \
        --source-dir %{mpi_bindir} \
        --yes

%preun
# Only unregister when uninstalling
if [ "$1" = "0" ]; then
	/usr/bin/mpi-selector --unregister %{name} --yes
	# Deregister the default if we are uninstalling it
	if [ "$(/usr/bin/mpi-selector --system --query)" = "%{name}" ]; then
		/usr/bin/mpi-selector --system --unset --yes
	fi
fi

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig
%else #!?with_hpc
# make it default
%post -n lib%{name} -p /sbin/ldconfig
%postun -n lib%{name} -p /sbin/ldconfig

%postun
%hpc_module_delete_if_default
%endif #!?with_hpc

%files
%defattr(-, root, root)
%doc NEWS README AUTHORS
%license LICENSE
%dir %{mpi_prefix}
%dir %{mpi_bindir}
%dir %{mpi_libdir}
%dir %{mpi_datadir}
%dir %{mpi_mandir}
%{mpi_bindir}/mpivars.csh
%{mpi_bindir}/mpivars.sh

%if %{without hpc}
%dir %{_libdir}/mpi
%dir %{_libdir}/mpi/gcc
%dir %{_datadir}/modules/gnu-openmpi
%{_datadir}/modules/gnu-openmpi/%{version}
%else # with hpc
%hpc_mpi_dirs
%hpc_modules_files
%endif # with hpc
#
%if 0%{?suse_version} <= 1315 && 0%{?sle_version} <= 120200
%dir %{mpi_datadir}/openmpi/doc
%{mpi_datadir}/openmpi/doc/COPYRIGHT-ptmalloc2.txt
%endif
#
%{mpi_bindir}/mpirun
%{mpi_bindir}/ompi-clean
%{mpi_bindir}/ompi-dvm
%{mpi_bindir}/ompi-ps
%{mpi_bindir}/ompi-server
%{mpi_bindir}/ompi-submit
%{mpi_bindir}/ompi-top
%{mpi_bindir}/ompi_info
%{mpi_bindir}/orte-clean
%{mpi_bindir}/orte-dvm
%{mpi_bindir}/orte-info
%{mpi_bindir}/orte-ps
%{mpi_bindir}/orte-server
%{mpi_bindir}/orte-submit
%{mpi_bindir}/orte-top
%{mpi_bindir}/orted
%{mpi_bindir}/orterun
%{mpi_bindir}/oshmem_info
%{mpi_bindir}/oshrun
%{mpi_bindir}/shmemrun

%dir %{mpi_datadir}/openmpi
%dir %{mpi_datadir}/openmpi/amca-param-sets
%{mpi_datadir}/openmpi/amca-param-sets/btl-openib-benchmark
%{mpi_datadir}/openmpi/amca-param-sets/example.conf
%{mpi_datadir}/openmpi/mca-btl-openib-device-params.ini
%{mpi_datadir}/openmpi/*-data.txt
%{mpi_datadir}/openmpi/help-*.txt

%files %{!?with_hpc:libs}%{?with_hpc:-n lib%{name}}
%defattr(-,root,root)
%dir %mpi_prefix/
%dir %mpi_libdir/
%mpi_libdir/*.so.*
%{mpi_libdir}/openmpi/*.so

%files devel
%defattr(-, root, root)
%dir %{mpi_libdir}/openmpi
%dir %{mpi_libdir}/pkgconfig
%{mpi_includedir}
%{mpi_libdir}/*.so
%{mpi_libdir}/pkgconfig/*.pc
%{mpi_libdir}/mpi.mod
%if 0%{?suse_version} >= 1320
%{mpi_libdir}/mpi_f08*.mod
%{mpi_libdir}/pmpi_f08*.mod
%endif
%{mpi_bindir}/mpiCC
%{mpi_bindir}/mpic++
%{mpi_bindir}/mpicc
%{mpi_bindir}/mpicxx
%{mpi_bindir}/mpiexec
%{mpi_bindir}/mpif77
%{mpi_bindir}/mpif90
%{mpi_bindir}/mpifort
%{mpi_bindir}/opal_wrapper
%{mpi_bindir}/ortecc
%{mpi_bindir}/oshcc
%{mpi_bindir}/oshfort
%{mpi_bindir}/shmemcc
%{mpi_bindir}/shmemfort
%{mpi_datadir}/openmpi/openmpi-valgrind.supp

%files docs
%defattr(-, root, root, -)
%{mpi_mandir}

%files macros-devel
%defattr(-,root,root,-)
%if %{with hpc}
%config %{_rpmmacrodir}/macros.hpc-openmpi
%else
%config %{_rpmmacrodir}/macros.openmpi
%endif

%if 0%{?build_static_devel}
%files devel-static
%defattr(-, root, root)
%{mpi_libdir}/*.la
%{mpi_libdir}/openmpi/*.la
%{mpi_libdir}/*.a
%{mpi_libdir}/openmpi/*.a
%endif

%if %{without hpc}
%files -n %{pname}%{m_f_ver}-config
%config %{_sysconfdir}/openmpi-default-hostfile
%config %{_sysconfdir}/openmpi-mca-params.conf
%{_sysconfdir}/openmpi-totalview.tcl
%endif

%endif # !?testsuite

%changelog
* Tue Sep 13 2022 nmoreychaisemartin@suse.com
- Add patch btl-openib-Add-support-for-newer-hardware.patch to support
  newer RDMA hardware (ConnectX 4 and 5 VF, ConnectX6 PF + VF and Broadcom adapters)
* Mon Jun 13 2022 nmoreychaisemartin@suse.com
- Backport upstream patches to fix compilation with autoconf >= 2.70
  - Fix-error-with-stricter-quoting-requirements-of-autoconf-2.70.patch
  - Always-include-the-stddef.h-header.patch
* Tue Oct 19 2021 nmoreychaisemartin@suse.com
- Move rpm macros to %%_rpmmacrodir (bsc#1191389)
* Wed Apr 28 2021 nmoreychaisemartin@suse.com
- openmpi2 is not the default openmpi anymore for releases > 15.3
* Thu Mar 19 2020 nmoreychaisemartin@suse.com
- Drop different package string between SLES and Leap (jsc#SLE-11846)
* Wed Dec  4 2019 normand@linux.vnet.ibm.com
- Add openmpi_disable_opal_fifo_test_issue5470.patch
  as long as upstream issue#5470 not solved for PowerPC
  https://github.com/open-mpi/ompi/issues/5470
* Fri Oct 25 2019 nmoreychaisemartin@suse.com
- Link against libnuma (bsc#1155120)
* Thu Oct 10 2019 nmoreychaisemartin@suse.com
- Fix conflict with other opoenmpi*-macros-devel
- Add conflict with older provider name to avoid issues during updates
- Add openmpi_prefix macro to openmpi-macros-devel
* Mon Sep 16 2019 normand@linux.vnet.ibm.com
- Add -ffat-lto-objects in spec to avoid build error
* Mon May 27 2019 nmoreychaisemartin@suse.com
- Provide openmpi for suse_version >= 1500
- Add macros package for non hpc flavour
* Mon May 27 2019 nmoreychaisemartin@suse.com
- Enable openmpi2 on ppc64
* Tue Apr 23 2019 nmoreychaisemartin@suse.com
- Fix bad INCLUDE path in module (bsc#1132949)
* Mon Apr  1 2019 nmoreychaisemartin@suse.com
- Add add-gen-p5-chip-pci-id-to-ini-file.patch:
  - Adds support for Broadcom 57500 adapters (bsc#1125651)
* Thu Feb 14 2019 nmoreychaisemartin@suse.com
- Update to openmpi 2.1.6 (bsc#1094689)
  - Many bug fixes. See NEWS for a complete list
* Tue Nov 27 2018 bwiedemann@suse.com
- Add reproducible.patch to make package build reproducible
  (boo#1047218, boo#1041090, boo#1084909)
* Sun Nov 18 2018 eich@suse.com
- Add macro _hpc_openmpi_modules for modules support (bsc#1116458).
* Mon Oct 15 2018 nmoreychaisemartin@suse.com
- Update to openmpi 2.1.5 (fate#326157)
  - Many bug fixes. See NEWS for a complete list
- Drop openmpi2-add-HCAs-to-mca-ini.patch as it was
  merged upstream.
* Mon Sep 10 2018 nmoreychaisemartin@suse.com
- Remove bashism in preun scriptlet
* Wed Sep  5 2018 nmoreychaisemartin@suse.com
- Fix handling of mpi-selector during updates (bsc#1098653)
* Sun Aug 19 2018 eich@suse.com
- macros.hpc-openmpi2:
  replace %%%%compiler_family by %%%%hpc_compiler_family
* Thu Jun  7 2018 jjolly@suse.com
- Updated openmpi2-add-HCAs-to-mca-ini.patch
  * Adds Broadcom BCM57414 NetXtreme-E RDMA Ethernet Controller (bsc#1094689)
* Fri May 18 2018 jjolly@suse.com
- Added openmpi2-add-HCAs-to-mca-ini.patch
  * Adds necessary parameters for QLogic Corp. FastLinQ QL41000 (bsc#1092257)
* Wed May  2 2018 eich@suse.com
- Create missing docs master package (bsc#1091714)
* Tue Mar 27 2018 nmoreychaisemartin@suse.com
- Update to openmpi 2.1.3
  - Update internal PMIx version to 1.2.5.
  - Fix a problem with ompi_info reporting using param option.
  - Correct PMPI_Aint_{add|diff} to be functions (not subroutines)
    in the Fortran mpi_f08 module.
  - Fix a problem when doing MPI I/O using data types with large
    extents in conjunction with MPI_TYPE_CREATE_SUBARRAY.  Thanks to
  - Fix a problem when opening many files using MPI_FILE_OPEN.
  - Fix a problem with debuggers failing to attach to a running job.
  - Fix a problem when using madvise and the OpenIB BTL.
  - Fix a problem in the Vader BTL that resulted in failures of
    IMB under certain circumstances.
  - Fix a problem preventing Open MPI from working under Cygwin.
  - Reduce some verbosity being emitted by the USNIC BTL under certain
    circumstances.
  - Fix a problem with misdirection of SIGKILL.
  - Replace use of posix_memalign with malloc for small allocations.
  - Fix a problem with Open MPI's out of band TCP network for file descriptors
    greater than 32767.
  - Plug a memory leak in MPI_Mem_free().
- Drop btl-vader-change-the-way-fast-boxes-are-used.patch as it
  merged upstream.
- Add fix-rdma-component-selection.patch to fix bad rdma component selection
  which can cause stall when running on multiple IB nodes (bsc#1087031)
* Mon Mar 26 2018 nmoreychaisemartin@suse.com
- Enable --enable-mpirun-prefix-by-default (bsc#1086821)
* Fri Feb  9 2018 cgoll@suse.com
- Fix summary in module files (bnc#1080259)
* Tue Jan 30 2018 eich@suse.com
- Use macro in mpivars.(c)sh to be independent of changes to the module
  setup for the compiler (boo#1078364).
* Wed Jan 17 2018 nmoreychaisemartin@suse.com
- Switch from gcc6 to gcc7 as additional compiler flavor for HPC on SLES.
- Fix library package requires - use HPC macro (boo#1074890)
- Fix rpm macro file.
- Only build openmpi2-config for the standard flavor
* Thu Dec  7 2017 nmoreychaisemartin@suse.com
- Add btl-vader-change-the-way-fast-boxes-are-used.patch to
  fix a SEGV on i386 systems
* Fri Oct 13 2017 nmoreychaisemartin@suse.com
- Fix pre/post install call to ldconfig
* Tue Oct 10 2017 nmoreychaisemartin@suse.com
- Add a ringdisabled flag to allow building only the standard flavor
  so not all flavors are pulled into staging rings
- Fix baselibs.conf generation (wrong directory and name)
* Fri Oct  6 2017 nmoreychaisemartin@suse.com
- Add conflicts between the macros-devel packages
* Mon Sep 25 2017 nmoreychaisemartin@suse.com
- Convert to multibuild.
- Move all the doc to the docs RPM
- Add HPC build using environment modules (FATE#321711).
- Resync spec with openmpi and openmpi3
* Mon Sep 25 2017 nmoreychaisemartin@suse.com
- Update to OpenMPI 2.1.2
  * Many bug fixes. See NEWS
- Fix VERSION file during build so that ompi_info reports good infos
* Tue Sep 19 2017 nmoreychaisemartin@suse.com
- Remove --disable-mca-dso
  Related bug was due to openmpi/*.so wrongly packaged as devel
* Fri Sep 15 2017 nmoreychaisemartin@suse.com
- Reenable fortan08 bindings as gcc >= 5 is now the default
- Remove devel-headers configure option (reserved for MPI plugins developers)
* Tue Sep 12 2017 nmoreychaisemartin@suse.com
- Update to 2.1.1.186.9a3ac9803c
- Drop openmpi-pmix-configure-ac.patch as it was merged upstream
* Wed Sep  6 2017 nmoreychaisemartin@suse.com
- Update to 2.1.1.176.7aa585d4ff (2.1.2rc3)
  * Too many bug fixes to list. See NEWS
  * ppc64be support was dropped
- Drop btl-vader-work-around-ob1-pending-fragment-bug.patch and
  pml-ob1-do-not-access-fragment-after-calling-btl-rget.patch as
  they were merged upstream.
- Package NEWS file
- Add openmpi-pmix-configure-ac.patch to fix
  a compilation issue on Leap 42.3/SLE12 SP3
* Tue Sep  5 2017 nmoreychaisemartin@suse.com
- Update _service to allow auto updates from github
* Sun Aug 13 2017 schwab@linux-m68k.org
- Enable ucx only on supported platforms
* Wed Jul 19 2017 nmoreychaisemartin@suse.com
- Fix module file name
* Wed Jul 12 2017 nmoreychaisemartin@suse.com
- Add pml-ob1-do-not-access-fragment-after-calling-btl-rget.patch and
  btl-vader-work-around-ob1-pending-fragment-bug.patch
  to fix upstream bug https://github.com/open-mpi/ompi/issues/3821
  which causes openmpi2 to fail the IMB test suite
* Tue Jul 11 2017 nmoreychaisemartin@suse.com
- Do not require openucx libs for suse_version < 1320
* Fri Jul  7 2017 nmoreychaisemartin@suse.com
- Cleanup upstream spec file
- Disable rpath in configure
* Thu Jun 29 2017 nmoreychaisemartin@suse.com
- Build with openucx support when it is available
- Buid plugins as part of the MPI library. Fixes:
  * Missing shmem support
  * Missing Requires in RPM
- Build with libfabric support on x86
* Wed Jun 28 2017 jengelh@inai.de
- Trim filler wording from description
- Replace uses of old $RPM_ variables, remove redundant %%clean
  section, abolish %%__-type macro indirection,
  remove excess piping to xargs
- Add missing %%_smp_mflags.
* Thu Jun 15 2017 nmoreychaisemartin@suse.com
- Add support for openmpi2 over PSM2 and libfabric
- Reference baselibs.conf and openmpi2-rpmlintrc in spec
- Add _service to fetch from upstream github repo
* Thu Jun  8 2017 nmoreychaisemartin@suse.com
- Remove version dependencies to libibumad and libibverbs
* Wed May 31 2017 nmoreychaisemartin@suse.com
- Fix module file paths
* Tue May 30 2017 nmoreychaisemartin@suse.com
- Add openmpi2-config package which contains runtime configuration
  files for OpenMPI 1 and/or 2
* Wed May 17 2017 nmoreychaisemartin@suse.com
- Update to OpenMPI 2.1.1
  * Fix a problem with one of Open MPI's fifo data structures which led to
    hangs in a make check test.
  * Add missing MPI_AINT_ADD/MPI_AINT_DIFF function definitions to mpif.h.
  * Fix the error return from MPI_WIN_LOCK when rank argument is invalid.
  * Fix a problem with mpirun/orterun when started under a debugger.
  * Add configury option to disable use of CMA by the vader BTL.
  * Add configury check for MPI_DOUBLE_COMPLEX datatype support.
  * Fix memory allocated by MPI_WIN_ALLOCATE_SHARED to
    be 64 byte aligned.
  * Update MPI_WTICK man page to reflect possibly higher
    resolution than 10e-6.
  * Add missing MPI_T_PVAR_SESSION_NULL definition to mpi.h
    include file.
  * Enhance the Open MPI spec file to install modulefile in /opt
    if installed in a non-default location.
  * Fix a problem with conflicting PMI symbols when linking statically.
  * S390/S390x support
- Drop openmpi2-ia32-fix-atomic.patch openmpi2-s390.patch as they are now
  fixed/supported upstream.
* Tue May  2 2017 nmoreychaisemartin@suse.com
- Add testsuite package
* Mon Apr 24 2017 nmoreychaisemartin@suse.com
- Initial packaging of OpenMPI 2.1.0
